@@ -1,10 +1,11 @@
-"""minos.networks.abc.consumers module."""
-
 from __future__ import (
     annotations,
 )
 
 import logging
+from itertools import (
+    chain,
+)
 from typing import (
     Any,
     NoReturn,
@@ -28,7 +29,7 @@ from minos.common import (
 )
 
 from ..decorators import (
-    EnrouteBuilder,
+    EnrouteAnalyzer,
 )
 from .abc import (
     HandlerSetup,
@@ -67,21 +68,18 @@ class Consumer(HandlerSetup):
     def _from_config(cls, config: MinosConfig, **kwargs) -> Consumer:
         topics = set()
 
-        # events
-        decorators = EnrouteBuilder(config.events.service, config).get_broker_event()
-        topics |= {decorator.topic for decorator in decorators.keys()}
-
         # commands
-        decorators = EnrouteBuilder(config.commands.service, config).get_broker_command_query()
-        topics |= {decorator.topic for decorator in decorators.keys()}
+        decorators = EnrouteAnalyzer(config.commands.service, config).get_broker_command_query_event()
+        topics |= {decorator.topic for decorator in chain(*decorators.values())}
 
         # queries
-        decorators = EnrouteBuilder(config.queries.service, config).get_broker_command_query()
-        topics |= {decorator.topic for decorator in decorators.keys()}
+        decorators = EnrouteAnalyzer(config.queries.service, config).get_broker_command_query_event()
+        topics |= {decorator.topic for decorator in chain(*decorators.values())}
 
         # replies
         topics |= {f"{config.service.name}Reply"}
 
+        # noinspection PyProtectedMember
         return cls(
             topics=topics, broker=config.broker, group_id=config.service.name, **config.broker.queue._asdict(), **kwargs
         )
@@ -128,6 +126,10 @@ class Consumer(HandlerSetup):
 
     @property
     def client(self) -> AIOKafkaConsumer:
+        """Get the kafka consumer client.
+
+        :return: An ``AIOKafkaConsumer`` instance.
+        """
         if self._client is None:  # pragma: no cover
             self._client = AIOKafkaConsumer(
                 *self._topics,
@@ -196,10 +198,6 @@ class Consumer(HandlerSetup):
         return row[0]
 
 
-_INSERT_QUERY = SQL(
-    "INSERT INTO consumer_queue (topic, partition_id, binary_data, creation_date) "
-    "VALUES (%s, %s, %s, NOW()) "
-    "RETURNING id"
-)
+_INSERT_QUERY = SQL("INSERT INTO consumer_queue (topic, partition, data) VALUES (%s, %s, %s) RETURNING id")
 
 _NOTIFY_QUERY = SQL("NOTIFY {}")
